@@ -16,6 +16,7 @@
 
 from files import (process, checkUtils, readFile, listDirectory,
                    getRunCommands, getProgPath)
+import device
 import sys
 import os
 import re
@@ -32,7 +33,6 @@ from calculate.lib.cl_lang import setLocalTranslate
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
-SYSFS_NET_PATH = "/sys/class/net"
 PROCFS_NET_PATH = "/proc/net/dev"
 
 # From linux/sockios.h
@@ -230,23 +230,23 @@ def getInterfaces():
     """
 
     def filter_ethernet(x):
-        full_dn = path.join(SYSFS_NET_PATH, x)
-        # исплючить loopback
-        if readFile(path.join(full_dn, "type")).strip() != "1":
+        # exclude loopback
+        if device.sysfs.read(x, "type").strip() != "1":
             return False
-        # если физическое утройство
-        if path.lexists(path.join(full_dn, "device")):
+        # physical device
+        if device.sysfs.exists(x, "device"):
             return True
-        # исключить мосты
-        if path.lexists(path.join(full_dn, "brport")):
+        # exclude bridges
+        if device.sysfs.exists(x, "brport"):
             return False
-        if path.lexists(path.join(full_dn, "bridge")):
+        if device.sysfs.exists(x, "bridge"):
             return False
         return True
 
-    return sorted(
-        filter(filter_ethernet,
-               listDirectory(SYSFS_NET_PATH)))
+    return sorted(path.basename(x)
+                  for x in device.sysfs.listdir(
+                    device.sysfs.Path.ClassNet, fullpath=True)
+                  if filter_ethernet(x))
 
 
 def getIp(iface):
@@ -317,7 +317,7 @@ def getOperState(iface):
     """
     Get interface state up or down
     """
-    if readFile("/sys/class/net/%s/operstate" % iface) == "down":
+    if device.sysfs.read(device.sysfs.Path.ClassNet, iface, "operstate") == "down":
         return "down"
     return "up"
 
